require 'uu/os/cmd/command_client'
require 'uu/os/env/environment'

module UU
  module OS
    module CMD

      # Updates server configuration using optional uu-client.properties and injects
      # this configuration to {UU::OS::CMD::CommandClient}.
      # @private
      class ConfigurationInjector # :nodoc:

        # Updates server configuration using optional uu-client.properties and injects
        # this configuration to {UU::OS::CMD::CommandClient}.
        # @private
        def self.on_server_startup(ctx) # :nodoc:
          # Update server configuration with uu-client.properties
          begin
            config = UU::OS::Env::Environment.load_configuration('config/uu-client.properties')
            if config.kind_of?(Hash)
              # Override values from configuration file by server environment
              config.merge!(ctx.configuration)
              # Merge back to server environment (to add additional configuration from file)
              ctx.configuration.merge!(config)
            end
          rescue ArgumentError
            # Configuration file was not found
          end
          # In case of development mode, also try to update command client configuration
          # so that all requests to the application are executed on embedded application
          # server (works only for tests where application server is started in the same
          # environment as the command client used).
          if ctx.development_mode?
            base_url = Thread.current[:BASE_URL]
            if !base_url.nil?
              ctx.instance_variable_get(:@builder).development_context_path.each do |context|
                if context.empty?
                  base_url_cfg_key = 'base_url'
                  routing_data_cfg_key = 'append_routing_data'
                else
                  base_url_cfg_key = "#{context.gsub(/(^\/)|(\/$)/, '').gsub(/[\/\-_]/, '.')}.cmd-server-url"
                  routing_data_cfg_key = "#{context.gsub(/(^\/)|(\/$)/, '').gsub(/[\/\-_]/, '.')}.cmd-append-routing-data"
                end
                ctx.configuration[base_url_cfg_key.downcase] = base_url
                ctx.configuration[routing_data_cfg_key.downcase] = "false"
              end
            end
          end

          # Inject configuration to command client.
          UU::OS::CMD::CommandClient.load_configuration(ctx.configuration)
        end

      end

    end
  end
end
